@@ -21,11 +21,11 @@
 #include <QProcess>
 #include <QTimer>
 #include <KConfigGroup>
-#include <klineedit.h>
+#include <KLineEdit>
 #include <ktoolinvocation.h>
-#include <kstandardguiitem.h>
+#include <KStandardGuiItem>
 #include <QAction>
-#include <kstandardaction.h>
+#include <KStandardAction>
 #include "kstatusnotifieritem.h"
 #include <KToolInvocation>
 #include <KHelpClient>
@@ -615,7 +615,7 @@ void KTimerJob::fire()
         d->processes.append( proc );
         connect(proc, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &KTimerJob::processExited);
         if (!d->command.simplified ().isEmpty()) {
-	        proc->start(d->command);
+                proc->start(d->command, QStringList());
 	        emit fired( this );
         }
         if(proc->state() == QProcess::NotRunning) {
